# pdf2wordx [Código](https://github.com/tutosrive/pdf2wordx/tree/main/src/pdf2wordx/)

[ES](README.md) | [CHN](https://github.com/tutosrive/pdf2wordx/blob/main/README/readme_pdf2wordx_chn.md) | [EN](https://github.com/tutosrive/pdf2wordx/blob/main/README/readme_pdf2wordx_en.md) | [RUS](https://github.com/tutosrive/pdf2wordx/blob/main/README/readme_pdf2wordx_rus.md) | [FRA](https://github.com/tutosrive/pdf2wordx/blob/main/README/readme_pdf2wordx_fra.md)

---

<div style="display: flex; align-items: center; justify-content: center; margin: 10px 0; gap: 10px; max-height: 48px; height: 48px;">
  <a href="https://github.com/sponsors/tutosrive" target="_blank">
  <img src="https://img.shields.io/badge/Sponsor-%F0%9F%92%96%20tutosrive-orange?style=for-the-badge&logo=github" alt="Sponsor me on GitHub">
</a>
  <a href="https://www.buymeacoffee.com/tutosrive">
    <img 
      src="https://img.shields.io/badge/buy_me_a_coffee-FFDD00?style=for-the-badge&logo=buy-me-a-coffee&logoColor=black" 
      style="height: 48px; width: auto; object-fit: contain; border-radius: 6px;" 
      alt="Buy me a coffee button">
  </a>
</div>

---

Descargas soruceforge.net ==> [![Download pdf2wordx Source Forget](https://img.shields.io/sourceforge/dt/pdf-to-word-docx.svg)](https://sourceforge.net/projects/pdf-to-word-docx/files/latest/download)

<!-- Badges -->
  <div>
<!-- Total downloads -->
    <a href="https://pepy.tech/projects/pdf2wordx"><img src="https://static.pepy.tech/badge/pdf2wordx" alt="PyPI Downloads"></a>
<!-- Versión actual -->
    <a href="https://pypi.org/project/pdf2wordx/"><img alt="PyPI - Version" src="https://img.shields.io/pypi/v/pdf2wordx?label=pdf2wordx"></a>
<!-- Python versions supported -->
    <a href="https://python.org/"><img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/pdf2wordx"></a> 
<!-- Author -->
    <a href="https://github.com/tutosrive"><img alt="Static Badge" src="https://img.shields.io/badge/Tutos%20Rive-Author-brightgreen"></a>
<!-- Licencia -->
    <a href="https://raw.githubusercontent.com/tutosrive/pdf2wordx/main/LICENSE"><img alt="GitHub License" src="https://img.shields.io/github/license/tutosrive/pdf2wordx"></a>
  </div>

```shell
pip install pdf2wordx
```
---

> ### Visite [pdf2wordx](https://tutosrive.github.io/pdf2wordx/) para más documentación

Convierte tus **PDF** a **DOCX** con este programa diseñado con interfaz gráfica (Python Tkinter).

En tan solo 2 clicks se convierte un **PDF** en un **DOCX**, usa la librería **_pdf2docx_** para realizar la conversión.

**Tener en cuenta**:

⚠ Los archivos **docx** en este caso, pueden ser de gran tamaño (MB)

⚠ Sólo se permite convertir **PDF**

⚠ Pueden haber errores en el contenido del **DOCX** (colores extraños, textos incoherentes e incluso pérdida de contenido), esto debido al contenido original del **PDF** (podría ser complicado de replicar)

## Pantallazos del programa:

<details>
    <summary>Imágenes pdftoword-V1.0</summary>
    <div>
        <p>Imagen 1:</p>
        <image name="img1" src="https://github.com/tutosrive/images-projects-srm-trg/raw/main/img-pdftoword/v1.0-Alpha/v1alpha-1.png">
    </div>
    <div>
        <p>Imagen 2:</p>
        <image name="img2" src="https://github.com/tutosrive/images-projects-srm-trg/raw/main/img-pdftoword/v1.0-Alpha/v1alpha-2.png">
    </div>
    <div>
        <p>Imagen 3:</p>
        <image name="img3" src="https://github.com/tutosrive/images-projects-srm-trg/raw/main/img-pdftoword/v1.0-Alpha/v1alpha-3.png">
    </div>
</details>

<details>
    <summary>Imágenes pdftoword-V2.0.0</summary>
    <p>Imagen 1:</p>
    <image src="https://github.com/tutosrive/images-projects-srm-trg/raw/main/img-pdftoword/v2.0.0-IMG/v2.0.0-1.webp">
    <p>Imagen 2:</p>
    <image src="https://github.com/tutosrive/images-projects-srm-trg/raw/main/img-pdftoword/v2.0.0-IMG/v2.0.0-2.webp">
    <p>Imagen 3:</p>
    <image src="https://github.com/tutosrive/images-projects-srm-trg/raw/main/img-pdftoword/v2.0.0-IMG/v2.0.0-3.webp">
    <p>Imagen 4:</p>
    <image src="https://github.com/tutosrive/images-projects-srm-trg/raw/main/img-pdftoword/v2.0.0-IMG/v2.0.0-4.webp">
    <p>Imagen 5:</p>
    <image src="https://github.com/tutosrive/images-projects-srm-trg/raw/main/img-pdftoword/v2.0.0-IMG/v2.0.0-5.webp">
</details>

<details>
    <summary>Imágenes pdftoword-V2.0.1</summary>
    <p>Imagen 1:</p>
    <image src="https://github.com/tutosrive/images-projects-srm-trg/raw/main/img-pdftoword/v2.0.1-IMG/v2.0.1-1.png">
    <p>Imagen 2:</p>
    <image src="https://github.com/tutosrive/images-projects-srm-trg/raw/main/img-pdftoword/v2.0.1-IMG/v2.0.1-2.png">
</details>

## ¿Tendrá actualizaciones?

Estaré subiendo en cuanto sea posible nuevas versiones del programa, con mejoras que tomaré por mi cuenta.

<a href="https://sourceforge.net/p/pdf-to-word-docx/"><img alt="Download pdf2wordx" src="https://sourceforge.net/sflogo.php?type=17&amp;group_id=3784635" width=200></a>

# Releases

<a href="https://github.com/tutosrive/pdf2wordx/releases/">Pdf TO Word Releases</a>
